
2023 OCT 16

*   Instead of sending back `data_envelope`-s directly, always enclose them in `envelope_container`-s.
*   Save command line into the shell history on `Alt+Shiff+Q`.
*   FS_66_17_43_42: improve test infra.
*   Fix escaping quotes in strings for JSON payload.
